@@ -1,4 +1,7 @@
-package Protocl::ACME::Challenge;
+package Protocol::ACME::Challenge;
+
+use strict;
+use warnings;
 
 =head1 NAME
 
@@ -7,7 +10,7 @@ Protocol::ACME::Challenge - Empty base class for ACME Challenges
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.11';
 
 
 1;
